<?php

include_once 'includes/custom_menu.inc';

/**
 * Implements hook_preprocess_html().
 */
function drive_preprocess_html(&$variables) {

  _drive_add_css();


  // Cache path to theme for duration of this function:
  $path_to_theme = drupal_get_path('theme', 'drive');
  // Add 'viewport' meta tag:
  drupal_add_html_head(
          array(
      '#tag' => 'meta',
      '#attributes' => array(
          'name' => 'viewport',
          'content' => 'width=device-width, initial-scale=1',
      ),
          ), 'drive:viewport_meta'
  );

  drupal_add_html_head(
          array(
      '#tag' => 'meta',
      '#attributes' => array(
          'name' => 'http_equiv',
          'content' => 'IE=edge,chrome=1',
          'http-equiv' => 'X-UA-Compatible',
      ),
          ), 'drive:http_equiv_meta'
  );
}

function drive_preprocess_page(&$vars) {

  $custom_main_menu = _custom_main_menu_render_superfish();
  if (!empty($custom_main_menu['content'])) {
    $vars['navigation'] = $custom_main_menu['content'];
  }

  if (arg(0) == 'node' && arg(1)) {
    $nid = arg(1);

    $node = node_load($nid);
    switch ($node->type) {
      case 'blog':
        $vars['title'] = t('Blog');

        break;
    }
  }
}

function drive_format_comma_field($field_category, $node, $limit = NULL) {
  $category_arr = array();
  $category = '';
  if (!empty($node->{$field_category}[LANGUAGE_NONE])) {
    foreach ($node->{$field_category}[LANGUAGE_NONE] as $item) {
      $term = taxonomy_term_load($item['tid']);
      if ($term) {
        $category_arr[] = l($term->name, 'taxonomy/term/' . $item['tid']);
      }

      if ($limit) {
        if (count($category_arr) == $limit) {
          $category = implode(', ', $category_arr);
          return $category;
        }
      }
    }
  }
  $category = implode(', ', $category_arr);

  return $category;
}

function drive_breadcrumb($variables) {
  $breadcrumb = $variables['breadcrumb'];
  $output = '';
  if (!empty($breadcrumb)) {
    // Provide a navigational heading to give context for breadcrumb links to
    // screen-reader users. Make the heading invisible with .element-invisible.
    $br = '';

    if (!empty($breadcrumb)) {
      $count_items = count($breadcrumb);
      $i = 0;
      foreach ($breadcrumb as $b) {
        $br .= '<li>' . $b . '</li>';
        if ($i < ($count_items - 1)) {
          $br .= '<span class="divider">/</span>';
        }

        $i++;
      }
    }
    $output .= '<ul class="breadcrumb">' . $br . '</ul>';
    return $output;
  }
}

function drive_form_alter(&$form, &$form_state, $form_id) {

  
  switch ($form_id) {
    case 'search_block_form':

      if (!empty($form['search_block_form'])) {
        $form['search_block_form']['#attributes']['placeholder'] = t('Search');
        $form['search_block_form']['#attributes']['class'][] = 'textfield';
        $form['search_block_form']['#suffix'] = '<button class="searchBtn" type="submit"><span class="search-icon"></span></button>';
      }
      if (!empty($form['actions'])) {
        unset($form['actions']);
      }
      break;
      
      case 'contact_site_form':
        
        if(!empty($form['name'])){
          $form['name']['#prefix'] = '<div class="span4">';
          $form['name']['#suffix'] = '</div>';
        }
        if(!empty($form['mail'])){
          $form['mail']['#prefix'] = '<div class="span4">';
          $form['mail']['#suffix'] = '</div>';
        }
        if(!empty($form['subject'])){
          $form['subject']['#prefix'] = '<div class="span4">';
          $form['subject']['#suffix'] = '</div>';
        }
        
        break;
  }

  if (!empty($form['actions']['submit'])) {
    $form['actions']['submit']['#attributes']['class'][] = 'btn btn-theme-pri';
  }

  if (!empty($form['actions']['preview'])) {
    $form['actions']['preview']['#attributes']['class'][] = 'btn btn-theme-pri';
  }

  if (isset($form['submit'])) {
    $form['submit']['#attributes']['class'] = array('btn btn-theme-pri');
  }
}

function _drive_add_css() {

  $theme_path = path_to_theme();


  $default_style = theme_get_setting('theme_color', 'drive');

  drupal_add_css($theme_path . '/css/fonts.css');
  drupal_add_css($theme_path . '/css/font-awesome.css');
  drupal_add_css($theme_path . '/css/bootstrap.css');
  drupal_add_css($theme_path . '/css/style.css');


  drupal_add_css($theme_path . '/colors-css/' . $default_style);
  drupal_add_css($theme_path . '/css/responsive.css');
  drupal_add_css($theme_path . '/css/sequence.css');
  drupal_add_css($theme_path . '/css/drive.css');
}